# -*- coding: utf-8 -*-
"""
Created on Wed Sep  2 19:59:46 2020

@author: hsauro
"""

# Example script, uses simplesbml to create a stoichiometry matrix 

import tellurium as te, simplesbml, numpy as np

r = te.loada("""
S0 + S3 -> S2; k0*S0*S3;
S3 + S2 -> S0; k1*S3*S2;
S5 -> S2 + S4; k2*S5;
S0 + S1 -> S3; k3*S0*S1;
S5 -> S0 + S4; k4*S5;
S0 -> S5; k5*S0;
S1 + S1 -> S5; k6*S1*S1;
S3 + S5 -> S1; k7*S3*S5;
S1 -> $S4 + S4; k8*S1;

S0 = 0; S1 = 0; S2 = 0; S3 = 0; S4 = 0; S5 = 0;
k0 = 0; k1 = 0; k2 = 0; k3 = 0; k4 = 0
k5 = 0; k6 = 0; k7 = 0; k8 = 0
""")

model = simplesbml.loadSBMLStr(r.getSBML())

# Allocate space for the stoichiometry matrix
stoich = np.zeros((model.getNumFloatingSpecies(), model.getNumReactions()))
for i in range (model.getNumFloatingSpecies()):
    floatingSpeciesId = model.getNthFloatingSpeciesId (i)
    
    for j in range (model.getNumReactions()):
        productStoichiometry = 0; reactantStoichiometry = 0

        numProducts = model.getNumProducts (j)
        for k1 in range (numProducts):
            productId = model.getProduct (j, k1)

            if (floatingSpeciesId == productId):
               productStoichiometry += model.getProductStoichiometry (j, k1)

        numReactants = model.getNumReactants(j)
        for k1 in range (numReactants):
            reactantId = model.getReactant (j, k1)
            if (floatingSpeciesId == reactantId):
               reactantStoichiometry += model.getReactantStoichiometry (j, k1)

        st = int(productStoichiometry - reactantStoichiometry)
        stoich[i,j] = st
    
print (stoich)




# -*- coding: utf-8 -*-
"""
Created on Tue Jan 27 23:13:42 2015, 2020

@author: carolc24, Kyle Medley, hsauro
"""

from __future__ import absolute_import, division, print_function, unicode_literals

from .simplesbml import SbmlModel
from .simplesbml import loadSBMLStr
from .simplesbml import loadSBMLFile

__version__ = '2.0.3'






# -*- coding: utf-8 -*-
"""
Created on Thu Feb 12 16:19:07 2015, 2020

@author: carolc24, Kyle Medley, Hebrert Sauro
"""

from setuptools import setup
import os.path

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(name='simplesbml',
      version='2.0.3',
      description='A simplified interface for constructing and accessing SBML docs. Version 2.0',
      author='Caroline Cannistra, Kyle Medley, Hebrert Sauro',
      author_email='tellurium-discuss@googlegroups.com',
      url='http://simplesbml.readthedocs.io/en/latest/',
      long_description=long_description,
      long_description_content_type='text/markdown',     
      install_requires=['tesbml>=5.15.0'],
      license='MIT',
      packages=['simplesbml'],
      classifiers=[
       'License :: OSI Approved :: MIT License',
       'Programming Language :: Python :: 3.7',
       'Programming Language :: Python :: 3.8',
       'Operating System :: OS Independent',
      ],
      python_requires='>=3.7',)
